@@ -3,7 +3,7 @@ package Params::ValidationCompiler::Compiler;
 use strict;
 use warnings;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Eval::Closure;
 use List::SomeUtils qw( first_index );
@@ -12,10 +12,17 @@ use Scalar::Util qw( blessed looks_like_number reftype );
 use overload ();
 
 BEGIN {
-    unless ( eval { require Sub::Name; Sub::Name->import('subname'); 1; } ) {
-        *subname = sub {
+    unless (
+        eval {
+            require Sub::Util;
+            Sub::Util->VERSION(1.40);
+            Sub::Util->import('set_subname');
+            1;
+        }
+        ) {
+        *set_subname = sub {
             die
-                "Cannot name a generated validation subroutine. Please install Sub::Name.\n";
+                "Cannot name a generated validation subroutine. Please install Sub::Util.\n";
         };
     }
 }
@@ -96,7 +103,7 @@ sub subref {
     if ( $self->_has_name ) {
         my $caller = $self->_has_caller ? $self->_caller : caller(1);
         my $name = join '::', $caller, $self->name;
-        subname( $name, $sub );
+        set_subname( $name, $sub );
     }
 
     return $sub;
@@ -653,7 +660,7 @@ Params::ValidationCompiler::Compiler - Object that implements the check subrouti
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =for Pod::Coverage .*
 
@@ -668,7 +675,7 @@ I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
